@@ -2,10 +2,10 @@ import tempfile
 import re
 import time
 import os
-import shutil
 import urllib.request
 import xml.etree.ElementTree as ET
 import pyfastaq
+from ariba import common
 
 class Error (Exception): pass
 
@@ -29,7 +29,7 @@ class PubmlstGetter:
         xml_tree = ET.parse(xml_file)
 
         if not self.debug:
-            shutil.rmtree(tmpdir)
+            common.rmtree(tmpdir)
 
         return xml_tree
 
@@ -105,7 +105,7 @@ class PubmlstGetter:
         self._download_file(profile_url, profile_outfile)
 
         for fasta_url in fasta_urls:
-            outfile = os.path.join(outdir, fasta_url.split('/')[-1])
+            outfile = "{0}.tfa".format(os.path.join(outdir, fasta_url.split('/')[-2]))
             self._download_file(fasta_url, outfile + '.tmp')
             PubmlstGetter._rename_seqs_in_fasta(outfile + '.tmp', outfile)
             os.unlink(outfile + '.tmp')
